statefulset

package
v0.0.0-...-79e99aa Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 2, 2026 License: BSD-3-Clause Imports: 23 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	ErrSkipReconciliationPhase = errors.New("skipping reconciliation phase")
)

Functions

func GetRevision

func GetRevision(ctx context.Context, r client.Client, doltdb *doltv1alpha.DoltDB) (string, error)

Types

type Reconciler

type Reconciler struct {
	client.Client
	// contains filtered or unexported fields
}

func NewReconciler

func NewReconciler(client client.Client, refResolver *refresolver.RefResolver, builder *builder.Builder) *Reconciler

NewReconciler creates a new with the given client.

func (*Reconciler) Reconcile

func (r *Reconciler) Reconcile(ctx context.Context, doltdb *doltv1alpha.DoltDB) (ctrl.Result, error)

Reconcile ensures that the desired StatefulSet is present in the cluster. If the StatefulSet does not exist, it will be created. If it exists, it will be updated if shouldUpdate is true.

func (*Reconciler) ReconcileWithUpdates

func (r *Reconciler) ReconcileWithUpdates(ctx context.Context, desiredSts *appsv1.StatefulSet) error

ReconcileWithUpdates ensures that the desired StatefulSet is present in the cluster. If the StatefulSet does not exist, it will be created. If it exists, it will be updated based on the shouldUpdate flag.

Jump to