Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var (
ErrSkipReconciliationPhase = errors.New("skipping reconciliation phase")
)
Functions ¶
func GetRevision ¶
Types ¶
type Reconciler ¶
func NewReconciler ¶
func NewReconciler(client client.Client, refResolver *refresolver.RefResolver, builder *builder.Builder) *Reconciler
NewReconciler creates a new with the given client.
func (*Reconciler) Reconcile ¶
func (r *Reconciler) Reconcile(ctx context.Context, doltdb *doltv1alpha.DoltDB) (ctrl.Result, error)
Reconcile ensures that the desired StatefulSet is present in the cluster. If the StatefulSet does not exist, it will be created. If it exists, it will be updated if shouldUpdate is true.
func (*Reconciler) ReconcileWithUpdates ¶
func (r *Reconciler) ReconcileWithUpdates(ctx context.Context, desiredSts *appsv1.StatefulSet) error
ReconcileWithUpdates ensures that the desired StatefulSet is present in the cluster. If the StatefulSet does not exist, it will be created. If it exists, it will be updated based on the shouldUpdate flag.
Click to show internal directories.
Click to hide internal directories.